_ATHANOR_RIGS = {
    "Standup M-Set Biochemical Reactor Material Efficiency I",
    "Standup M-Set Biochemical Reactor Time Efficiency I",
    "Standup M-Set Composite Reactor Material Efficiency I",
    "Standup M-Set Composite Reactor Time Efficiency I",
    "Standup M-Set Hybrid Reactor Material Efficiency I",
    "Standup M-Set Hybrid Reactor Time Efficiency I",
    "Standup M-Set Biochemical Reactor Material Efficiency II",
    "Standup M-Set Biochemical Reactor Time Efficiency II",
    "Standup M-Set Composite Reactor Material Efficiency II",
    "Standup M-Set Composite Reactor Time Efficiency II",
    "Standup M-Set Hybrid Reactor Material Efficiency II",
    "Standup M-Set Hybrid Reactor Time Efficiency II",
    "Standup M-Set Advanced Component Manufacturing Material Efficiency I",
    "Standup M-Set Advanced Component Manufacturing Time Efficiency I",
    "Standup M-Set Advanced Large Ship Manufacturing Material Efficiency I",
    "Standup M-Set Advanced Large Ship Manufacturing Time Efficiency I",
    "Standup M-Set Advanced Medium Ship Manufacturing Material Efficiency I",
    "Standup M-Set Advanced Medium Ship Manufacturing Time Efficiency I",
    "Standup M-Set Advanced Small Ship Manufacturing Material Efficiency I",
    "Standup M-Set Advanced Small Ship Manufacturing Time Efficiency I",
    "Standup M-Set Ammunition Manufacturing Material Efficiency I",
    "Standup M-Set Ammunition Manufacturing Time Efficiency I",
    "Standup M-Set Basic Capital Component Manufacturing Material Efficiency I",
    "Standup M-Set Basic Capital Component Manufacturing Time Efficiency I",
    "Standup M-Set Basic Large Ship Manufacturing Material Efficiency I",
    "Standup M-Set Basic Large Ship Manufacturing Time Efficiency I",
    "Standup M-Set Basic Medium Ship Manufacturing Material Efficiency I",
    "Standup M-Set Basic Medium Ship Manufacturing Time Efficiency I",
    "Standup M-Set Basic Small Ship Manufacturing Material Efficiency I",
    "Standup M-Set Basic Small Ship Manufacturing Time Efficiency I",
    "Standup M-Set Drone and Fighter Manufacturing Material Efficiency I",
    "Standup M-Set Drone and Fighter Manufacturing Time Efficiency I",
    "Standup M-Set Equipment Manufacturing Material Efficiency I",
    "Standup M-Set Equipment Manufacturing Time Efficiency I",
    "Standup M-Set Structure Manufacturing Material Efficiency I",
    "Standup M-Set Structure Manufacturing Time Efficiency I",
    "Standup M-Set Thukker Advanced Component Manufacturing Material Efficiency",
    "Standup M-Set Thukker Basic Capital Component Manufacturing Material Efficiency",
    "Standup M-Set Advanced Component Manufacturing Material Efficiency II"
}

_TATARA_RIGS = {
    "Standup L-Set Reactor Efficiency I",
    "Standup L-Set Reactor Efficiency II",
    "Standup L-Set Advanced Component Manufacturing Efficiency I",
    "Standup L-Set Advanced Large Ship Manufacturing Efficiency I",
    "Standup L-Set Advanced Medium Ship Manufacturing Efficiency I",
    "Standup L-Set Advanced Small Ship Manufacturing Efficiency I",
    "Standup L-Set Ammunition Manufacturing Efficiency I",
    "Standup L-Set Basic Capital Component Manufacturing Efficiency I",
    "Standup L-Set Basic Large Ship Manufacturing Efficiency I",
    "Standup L-Set Basic Medium Ship Manufacturing Efficiency I",
    "Standup L-Set Basic Small Ship Manufacturing Efficiency I",
    "Standup L-Set Capital Ship Manufacturing Efficiency I",
    "Standup L-Set Drone and Fighter Manufacturing Efficiency I",
    "Standup L-Set Equipment Manufacturing Efficiency I",
    "Standup L-Set Structure Manufacturing Efficiency I",
    "Standup L-Set Thukker Advanced Component Manufacturing Efficiency",
    "Standup L-Set Thukker Basic Capital Component Manufacturing Efficiency",
    "Standup L-Set Advanced Component Manufacturing Efficiency II",
    "Standup L-Set Advanced Large Ship Manufacturing Efficiency II",
    "Standup L-Set Advanced Medium Ship Manufacturing Efficiency II",
    "Standup L-Set Advanced Small Ship Manufacturing Efficiency II",
    "Standup L-Set Capital Ship Manufacturing Efficiency II",
    "Standup L-Set Ammunition Manufacturing Efficiency II",
    "Standup L-Set Basic Capital Component Manufacturing Efficiency II",
    "Standup L-Set Basic Large Ship Manufacturing Efficiency II",
    "Standup L-Set Basic Medium Ship Manufacturing Efficiency II",
    "Standup L-Set Basic Small Ship Manufacturing Efficiency II",
    "Standup L-Set Drone and Fighter Manufacturing Efficiency II",
    "Standup L-Set Equipment Manufacturing Efficiency II",
    "Standup L-Set Structure Manufacturing Efficiency II"
}

_RAITARU_RIGS = {
    "Standup M-Set Advanced Component Manufacturing Material Efficiency I",
    "Standup M-Set Advanced Component Manufacturing Time Efficiency I",
    "Standup M-Set Advanced Large Ship Manufacturing Material Efficiency I",
    "Standup M-Set Advanced Large Ship Manufacturing Time Efficiency I",
    "Standup M-Set Advanced Medium Ship Manufacturing Material Efficiency I",
    "Standup M-Set Advanced Medium Ship Manufacturing Time Efficiency I",
    "Standup M-Set Advanced Small Ship Manufacturing Material Efficiency I",
    "Standup M-Set Advanced Small Ship Manufacturing Time Efficiency I",
    "Standup M-Set Ammunition Manufacturing Material Efficiency I",
    "Standup M-Set Ammunition Manufacturing Time Efficiency I",
    "Standup M-Set Basic Capital Component Manufacturing Material Efficiency I",
    "Standup M-Set Basic Capital Component Manufacturing Time Efficiency I",
    "Standup M-Set Basic Large Ship Manufacturing Material Efficiency I",
    "Standup M-Set Basic Large Ship Manufacturing Time Efficiency I",
    "Standup M-Set Basic Medium Ship Manufacturing Material Efficiency I",
    "Standup M-Set Basic Medium Ship Manufacturing Time Efficiency I",
    "Standup M-Set Basic Small Ship Manufacturing Material Efficiency I",
    "Standup M-Set Basic Small Ship Manufacturing Time Efficiency I",
    "Standup M-Set Drone and Fighter Manufacturing Material Efficiency I",
    "Standup M-Set Drone and Fighter Manufacturing Time Efficiency I",
    "Standup M-Set Equipment Manufacturing Material Efficiency I",
    "Standup M-Set Equipment Manufacturing Time Efficiency I",
    "Standup M-Set Structure Manufacturing Material Efficiency I",
    "Standup M-Set Structure Manufacturing Time Efficiency I",
    "Standup M-Set Thukker Advanced Component Manufacturing Material Efficiency",
    "Standup M-Set Thukker Basic Capital Component Manufacturing Material Efficiency",
    "Standup M-Set Advanced Component Manufacturing Material Efficiency II",
    "Standup M-Set Advanced Component Manufacturing Time Efficiency II",
    "Standup M-Set Advanced Large Ship Manufacturing Material Efficiency II",
    "Standup M-Set Advanced Large Ship Manufacturing Time Efficiency II",
    "Standup M-Set Advanced Medium Ship Manufacturing Material Efficiency II",
    "Standup M-Set Advanced Medium Ship Manufacturing Time Efficiency II",
    "Standup M-Set Advanced Small Ship Manufacturing Material Efficiency II",
    "Standup M-Set Advanced Small Ship Manufacturing Time Efficiency II",
    "Standup M-Set Ammunition Manufacturing Material Efficiency II",
    "Standup M-Set Ammunition Manufacturing Time Efficiency II",
    "Standup M-Set Basic Capital Component Manufacturing Material Efficiency II",
    "Standup M-Set Basic Capital Component Manufacturing Time Efficiency II",
    "Standup M-Set Basic Large Ship Manufacturing Material Efficiency II",
    "Standup M-Set Basic Large Ship Manufacturing Time Efficiency II",
    "Standup M-Set Basic Medium Ship Manufacturing Material Efficiency II",
    "Standup M-Set Basic Medium Ship Manufacturing Time Efficiency II",
    "Standup M-Set Basic Small Ship Manufacturing Material Efficiency II",
    "Standup M-Set Basic Small Ship Manufacturing Time Efficiency II",
    "Standup M-Set Drone and Fighter Manufacturing Material Efficiency II",
    "Standup M-Set Drone and Fighter Manufacturing Time Efficiency II",
    "Standup M-Set Equipment Manufacturing Material Efficiency II",
    "Standup M-Set Equipment Manufacturing Time Efficiency II",
    "Standup M-Set Structure Manufacturing Material Efficiency II",
    "Standup M-Set Structure Manufacturing Time Efficiency II"
}

_AZBEL_RIGS = {
    "Standup L-Set Advanced Component Manufacturing Efficiency I",
    "Standup L-Set Advanced Large Ship Manufacturing Efficiency I",
    "Standup L-Set Advanced Medium Ship Manufacturing Efficiency I",
    "Standup L-Set Advanced Small Ship Manufacturing Efficiency I",
    "Standup L-Set Ammunition Manufacturing Efficiency I",
    "Standup L-Set Basic Capital Component Manufacturing Efficiency I",
    "Standup L-Set Basic Large Ship Manufacturing Efficiency I",
    "Standup L-Set Basic Medium Ship Manufacturing Efficiency I",
    "Standup L-Set Basic Small Ship Manufacturing Efficiency I",
    "Standup L-Set Capital Ship Manufacturing Efficiency I",
    "Standup L-Set Drone and Fighter Manufacturing Efficiency I",
    "Standup L-Set Equipment Manufacturing Efficiency I",
    "Standup L-Set Structure Manufacturing Efficiency I",
    "Standup L-Set Thukker Advanced Component Manufacturing Efficiency",
    "Standup L-Set Thukker Basic Capital Component Manufacturing Efficiency",
    "Standup L-Set Advanced Component Manufacturing Efficiency II",
    "Standup L-Set Advanced Large Ship Manufacturing Efficiency II",
    "Standup L-Set Advanced Medium Ship Manufacturing Efficiency II",
    "Standup L-Set Advanced Small Ship Manufacturing Efficiency II",
    "Standup L-Set Capital Ship Manufacturing Efficiency II",
    "Standup L-Set Ammunition Manufacturing Efficiency II",
    "Standup L-Set Basic Capital Component Manufacturing Efficiency II",
    "Standup L-Set Basic Large Ship Manufacturing Efficiency II",
    "Standup L-Set Basic Medium Ship Manufacturing Efficiency II",
    "Standup L-Set Basic Small Ship Manufacturing Efficiency II",
    "Standup L-Set Drone and Fighter Manufacturing Efficiency II",
    "Standup L-Set Equipment Manufacturing Efficiency II",
    "Standup L-Set Structure Manufacturing Efficiency II"
}

_SOTIYO_RIGS = {
    "Standup XL-Set Equipment and Consumable Manufacturing Efficiency I",
    "Standup XL-Set Ship Manufacturing Efficiency I",
    "Standup XL-Set Structure and Component Manufacturing Efficiency I",
    "Standup XL-Set Thukker Structure and Component Manufacturing Efficiency",
    "Standup XL-Set Equipment and Consumable Manufacturing Efficiency II",
    "Standup XL-Set Ship Manufacturing Efficiency II",
    "Standup XL-Set Structure and Component Manufacturing Efficiency II"
}


AVAIABLE_RIGS = _ATHANOR_RIGS | _TATARA_RIGS | _RAITARU_RIGS | _AZBEL_RIGS | _SOTIYO_RIGS
