{% extends 'allianceauth/base-bs5.html' %}
{% load django_bootstrap5 %}

{% block page_title %}Ravworks Exporter{% endblock page_title %}

{% block content %}
    <div class="col-lg-12">
        <h1 class="page-header text-center">Ravworks Exporter</h1>
        <div class="card">
            <div class="card-body">
                <form enctype="multipart/form-data" method="post"> {% csrf_token %}
                    {% bootstrap_form form %}
                    <button type="submit" class="btn btn-primary">Submit</button>
                </form>
            </div>
        </div>
    </div>
{% endblock content %}